.. _api:

===================
Bolos API reference
===================

This page contains the documentation of the ``BOLOS`` API.


The :mod:`solver` Module
------------------------

.. automodule:: bolos.solver
    :members:
    :undoc-members:
    :show-inheritance:

The :mod:`grid` Module
----------------------

.. automodule:: bolos.grid
    :members:
    :undoc-members:
    :show-inheritance:


The :mod:`parser` Module
-------------------------

.. automodule:: bolos.parser
    :members:
    :undoc-members:
    :show-inheritance:
